import { init as csRenderInit } from "@cornerstonejs/core";
import dicomParser from "dicom-parser";
import * as cornerstone from "@cornerstonejs/core";
import cornerstoneDICOMImageLoader from "@cornerstonejs/dicom-image-loader";

const initCornerstoneDICOMImageLoader = () => {
  const { preferSizeOverAccuracy, useNorm16Texture } =
    cornerstone.getConfiguration().rendering;

  cornerstoneDICOMImageLoader.external.cornerstone = cornerstone;
  cornerstoneDICOMImageLoader.external.dicomParser = dicomParser;
  cornerstoneDICOMImageLoader.configure({
    useWebWorkers: true,
    decodeConfig: {
      convertFloatPixelDataToInt: false,
      use16BitDataType: preferSizeOverAccuracy || useNorm16Texture,
    },
  });

  const config = {
    maxWebWorkers: navigator.hardwareConcurrency ?? 7,
    startWebWorkersOnDemand: false,
    taskConfiguration: {
      decodeTask: {
        initializeCodecsOnStartup: false,
        strict: false,
      },
    },
  };

  cornerstoneDICOMImageLoader.webWorkerManager.initialize(config);
};

export const initCornerstone = async () => {
  initCornerstoneDICOMImageLoader();
  await csRenderInit();
};
